!> \file output_greeneem_mod-0.4.f90
!! Module pour les output
!<

!> \namespace  output_greeneem_mod
!! Module pour les output
!! \author Catherine
!! \date ...
!! @note Used module
!! @note   - use module3D_phy
!! @note   - use param_phy_mod
!<

module  output_greeneem_mod

use module3d_phy
use param_phy_mod

implicit none
      

!!$real ::  bmean                        !< bilan de masse moyen
!!$real ::  accmean                      !< accumulation moyenne
!!$real ::  ablmean                      !< ablation moyenne
!!$real ::  calvmean                     !< moyenne calving
!!$real ::  ablbordmean                  !< ablation sur les bords
!!$real ::  bmeltmean                    !< moyenne fusion basale
!!$real ::  tbmean                       !< temperature basale moyenne
!!$real ::  vsmean                       !< vitesse de surface moyenne
!!$real ::  hdotmean                     !< moyenne derivee / temps de h
!!$real ::  bdotmean                     !< moyenne bedrock derive / temps
!!$real ::  volf                         !< volume au dessus de la flottaison
!!$real ::  volg                         !< volume glace posee
!!$real ::  vol_shelf                    !< volume ice shelf
!!$integer :: npg                        !< nombre de points englaces-poses
!!$integer :: nf                         !< nombre de points englaces-flottants
!!$integer :: nabl                       !< nombre de points zone d'ablation
integer,parameter :: nbregion=2       ! nbr de zones geographiques
logical,dimension(nx,ny,nbregion) :: mask_cal ! masque regions calotte 
integer, dimension(nx,ny) :: write_mask

CONTAINS

subroutine init_outshort

ndisp=100                             ! ndisp sortie courte tous les ndisp

mask_cal(:,:,:)=.false.
mask_cal(:,:,1)=.true.
sum_H_old = sum(H(:,:),mask=ice(:,:)==1)
do j=1,ny
   do i=1,nx
! -- Groenland 
      IF ( (((xlong(i,j).ge.290).AND.(xlong(i,j).le.350)).AND. &
           ((ylat(i,j).ge.79.5).AND.(ylat(i,j).le.85))).OR.      &
           (((xlong(i,j).ge.286).AND.(xlong(i,j).lt.345)).AND. &
           ((ylat(i,j).ge.75).AND.(ylat(i,j).le.79.5))).OR.      &
           (((xlong(i,j).ge.300).AND.(xlong(i,j).le.345)).AND. &
           ((ylat(i,j).ge.67).AND.(ylat(i,j).le.75))).OR.    &
           (((xlong(i,j).ge.305).AND.(xlong(i,j).le.330)).AND. &
           ((ylat(i,j).ge.55).AND.(ylat(i,j).le.67))) ) mask_cal(i,j,2)=.true.
   enddo
enddo
!!!! Attention au formatage !!!!
WRITE(num_ritz, '(a134)')         "! greeneem15 :   time, isvol,   inp,isvolf,isvol_shelf,inf,isacc,isabl,isablbord,ablatot,iscalv,isbm,Tjulymean,Hmean,Hmax, nabl,  nacc"
WRITE(num_ritz, '(a134)')         "! IS         :      1      2      3      4      5      6      7      8      9     10     11     12     13     14     15     16     17 "
WRITE(num_ritz, '(a21,16(5x,i2))')'! Greenland  :       ',((i),i=18,33)
end subroutine init_outshort



!_________________________________________________________________________
subroutine shortoutput
  

  real,dimension(nbregion) :: isvol ! vol calotte posee
  real,dimension(nbregion) :: isvolf ! vol calotte au-dessus flottaison
  real,dimension(nbregion) :: isvol_shelf ! vol calotte au-dessus flottaison
  integer,dimension(nbregion) :: inp ! surface posee
  integer,dimension(nbregion) :: inf ! surface flottante
  real,dimension(nbregion) :: isacc ! acc moy sur calotte posee
  real,dimension(nbregion) :: isabl ! abl moy sur calotte posee
  real,dimension(nbregion) :: isablbord ! abl sur les bords calotte
  real,dimension(nbregion) :: ablatot ! abl totale : abl + ablbord
  real,dimension(nbregion) :: iscalv ! calving
  real,dimension(nbregion) :: isbm ! isacc + isabl + iscalv + isablbord
  real,dimension(nbregion) :: Tjulytot ! total Tjuly sur calotte
  real,dimension(nbregion) :: Tjulymean ! moy Tjuly sur calotte posee
  real,dimension(nbregion) :: Hmean ! Epaisseur moyenne calotte posee
  real,dimension(nbregion) :: Hmax ! Epaisseur max calotte posee
  integer,dimension(nbregion) :: nabl ! nbr points zone d'ablation
  integer,dimension(nbregion) :: nacc ! nbr points zone d'accumulation
  real,dimension(nbregion) :: Tacc ! acc sur zone englacee (glace pose + shelf)
  real,dimension(nbregion) :: Tbm ! bm total (acc+abl+calv+ablbord) sur zone englacee (glace pose + shelf)

  integer :: kk

  DO kk = 1,nbregion
     INP(kk) = 0
     INF(kk) = 0
     isvol(kk) = 0.
     isvol_shelf(kk)=0.
     Tjulytot(kk)=0.
     isacc(kk) = 0.
     isabl(kk) = 0.
     nabl(kk) = 0
     nacc(kk) = 0
     Tjulymean(kk) = 0.
     Hmax(kk) = 0.
     Tacc(kk) = 0.
     isablbord(kk) = 0.
     iscalv(kk) = 0.
     ablatot(kk)= 0.
     isbm(kk) = 0.
     Tbm(kk) = 0.
     isvolf(kk) = 0.


     ! nouveau tof mai 2009
     !        where (mask_cal(:,:,kk).and.H(:,:).gt.2..and.flot(:,:)) ISVOLF(kk) = ISVOLF(kk) + H(I,J)

     INF(kk) = count(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and.flot(:,:))
     INP(kk) = count(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:))
     isvol(kk) = sum(H(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     isvol_shelf(kk) = sum(H(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and.flot(:,:)))
     Tjulytot(kk) = sum(Tjuly(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     isacc(kk) = sum(Acc(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     isabl(kk) = sum(Abl(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     nabl(kk) = count(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:).and.BM(:,:).LT.0.)
     nacc(kk) = count(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:).and.BM(:,:).GT.0.)
     Tjulymean(kk) = sum(Tjuly(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     Hmax(kk) = maxval(H(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.).and..not.flot(:,:)))
     Tacc(kk) = sum(Acc(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.)))
     isablbord(kk) = sum(ablbord(:,:),mask=(mask_cal(:,:,kk)))
     iscalv(kk) =  sum(calv(:,:),mask=(mask_cal(:,:,kk).and.(H(:,:).gt.2.)))/dt

     ablatot(kk) = isabl(kk) + isablbord(kk)
     isbm(kk) = isacc(kk)+isabl(kk)+iscalv(kk)+isablbord(kk)
     Tbm(kk) = Tacc(kk)+isabl(kk)+iscalv(kk)+isablbord(kk)

     do j=1,ny
        do i=1,nx
           if (mask_cal(i,j,k).and..not.flot(i,j).and.H(i,j).GT.1..and.((sealevel-B(i,j)).LE.0.)) then
              isvolf(kk) = isvolf(kk) + H(i,j)
           else
              isvolf(kk) = isvolf(kk) + H(i,j)-row/ro*(sealevel-B(i,j))
           endif
        enddo
     enddo



     ! == Les moyennes      
     IF(INP(KK).ne.0)THEN
        Hmean(KK) = isvol(KK) / INP(KK)
        Tjulymean(KK)   = Tjulytot(KK) / INP(KK)
     ENDIF
     ! == Les volmes intergrées (3D)
     isvol(kk) = isvol(kk)*dx*dy     
     isacc(kk)=isacc(kk)*dx*dy
     isabl(kk)=isabl(kk)*dx*dy
     isablbord(kk)=isablbord(kk)*dx*dy
     ablatot(kk)=ablatot(kk)*dx*dy
     iscalv(kk)=iscalv(kk)*dx*dy
     isbm(kk)=isbm(kk)*dx*dy
     tacc(kk)=tacc(kk)*dx*dy
     tbm(kk)=tbm(kk)*dx*dy
  enddo
  
	
  

!  write(num_ritz,905)   time,((isvol(kk),inp(kk),isvolf(kk),isvol_shelf(kk),inf(kk),isacc(kk),isabl(kk),    &  
!       isablbord(kk),ablatot(kk),iscalv(kk),isbm(kk),Tjulymean(kk),Hmean(kk),Hmax(kk),nabl(kk),nacc(kk)),kk=1,nbregion)

  write(num_ritz,906) time,diff_H,water_bilan,sum(calv_dtt(2:nx-1,2:ny-1))/dtt, &
			 sum(ablbord_dtt(2:nx-1,2:ny-1))/dtt, &
			 sum(Bm_dtt(2:nx-1,2:ny-1))/dtt,sum(bmelt_dtt(2:nx-1,2:ny-1))/dtt,sum(ice(2:nx-1,2:ny-1),mask=ice(2:nx-1,2:ny-1)==1) 

905  format(f10.1,1x,2(e11.4, 1x, i5, 1x, e11.4, 1x, e11.4, 1x, i5, 9(1x, e12.5),2(1x,i5)))
906  format (f0.2,6(1x,e15.8),1x,i7)
         
! pour verifier la zone groenland sur carte 
!  where (mask_cal(:,:,2))
!     Tann(:,:)=40.
!  endwhere
  

end subroutine shortoutput
end module  output_greeneem_mod
